paulicirc.utils.numpy
=====================

.. automodule:: paulicirc.utils.numpy

BoolArray1D
-----------

.. autodata:: paulicirc.utils.numpy.BoolArray1D

Complex128Array1D
-----------------

.. autodata:: paulicirc.utils.numpy.Complex128Array1D

Complex128Array2D
-----------------

.. autodata:: paulicirc.utils.numpy.Complex128Array2D

ComplexArray1D
--------------

.. autodata:: paulicirc.utils.numpy.ComplexArray1D

FloatArray1D
------------

.. autodata:: paulicirc.utils.numpy.FloatArray1D

RNG
---

.. autoclass:: paulicirc.utils.numpy.RNG
    :show-inheritance:
    :members:

ShapeT
------

.. autodata:: paulicirc.utils.numpy.ShapeT

UInt16Array1D
-------------

.. autodata:: paulicirc.utils.numpy.UInt16Array1D

UInt8Array1D
------------

.. autodata:: paulicirc.utils.numpy.UInt8Array1D

UInt8Array2D
------------

.. autodata:: paulicirc.utils.numpy.UInt8Array2D

canonicalize_phase
------------------

.. autofunction:: paulicirc.utils.numpy.canonicalize_phase

numba_jit
---------

.. autofunction:: paulicirc.utils.numpy.numba_jit
